@@ -1,11 +1,20 @@
 from datetime import datetime
 from pydantic import BaseModel
-from .Enums import UserAcountHistoryTypes, GameMode, BeatmapsetDownload, UserListFilters, UserListSorts, UserListViews
+from .Enums import (
+    UserAcountHistoryTypes,
+    GameMode,
+    BeatmapsetDownload,
+    UserListFilters,
+    UserListSorts,
+    UserListViews,
+)
+
 
 # https://osu.ppy.sh/docs/index.html#usergroup
 class UserGroup(BaseModel):
     playmodes: list[GameMode] | None
-    
+
+
 # https://osu.ppy.sh/docs/index.html#usercompact-useraccounthistory
 class UserAccountHistory(BaseModel):
     description: str | None
@@ -14,34 +23,38 @@ class UserAccountHistory(BaseModel):
     permanent: bool
     timestamp: datetime
     type: UserAcountHistoryTypes
-    
+
     class Config:
         arbitrary_types_allowed = True
         json_encoders = {
             datetime: str,
         }
 
+
 # https://osu.ppy.sh/docs/index.html#usercompact-userbadge
 class UserBadge(BaseModel):
     awarded_at: datetime
     description: str
     image_url: str
     url: str
-    
+
     class Config:
         arbitrary_types_allowed = True
         json_encoders = {
-            datetime: str, 
+            datetime: str,
         }
-    
+
+
 class UserMonthlyPlaycount(BaseModel):
     start_date: str
     count: int
 
+
 class UserAchievement(BaseModel):
     achieved_at: str
     achievement_id: int | None
 
+
 class UserProfileCustomization(BaseModel):
     audio_autoplay: bool | None
     audio_muted: bool | None
@@ -57,4 +70,4 @@ class UserProfileCustomization(BaseModel):
     user_list_view: UserListViews | None
 
     class Config:
-        arbitrary_types_allowed = True
\ No newline at end of file
+        arbitrary_types_allowed = True
